@@ -1,8 +1,7 @@
 // Matrix manipulations.
 /*
 
-Copyright (C) 1993, 1994, 1995, 1996, 1997, 2002, 2005, 2007
-              John W. Eaton
+Copyright (C) 1993-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -35,9 +34,3 @@ along with Octave; see the file COPYING.  If not, see
 #include "mx-ops.h"
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
