@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009 John W. Eaton
+Copyright (C) 2003-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,41 +23,44 @@ along with Octave; see the file COPYING.  If not, see
 #if !defined (octave_charNDArray_h)
 #define octave_charNDArray_h 1
 
-#include "MArrayN.h"
+#include "Array.h"
 #include "chMatrix.h"
 
 #include "mx-defs.h"
 #include "mx-op-decl.h"
+#include "bsxfun-decl.h"
 
 class
 OCTAVE_API
-charNDArray : public MArrayN<char>
+charNDArray : public Array<char>
 {
 public:
 
-  charNDArray (void) : MArrayN<char> () { }
+  typedef charMatrix matrix_type;
 
-  charNDArray (const dim_vector& dv) : MArrayN<char> (dv) { }
+  charNDArray (void) : Array<char> () { }
 
-  charNDArray (const dim_vector& dv, char val) : MArrayN<char> (dv, val) { }
-  
-  charNDArray (const charNDArray& a) : MArrayN<char> (a) { }
+  charNDArray (const dim_vector& dv) : Array<char> (dv) { }
 
-  charNDArray (const charMatrix& a) : MArrayN<char> (a) { }
+  charNDArray (const dim_vector& dv, char val) : Array<char> (dv, val) { }
 
-  charNDArray (char c) : MArrayN<char> (charMatrix (c)) { }
+  charNDArray (const charNDArray& a) : Array<char> (a) { }
 
-  charNDArray (const char *s) : MArrayN<char> (charMatrix (s)) { }
+  charNDArray (const charMatrix& a) : Array<char> (a) { }
 
-  charNDArray (const std::string& s) : MArrayN<char> (charMatrix (s)) { }
+  charNDArray (char c) : Array<char> (charMatrix (c)) { }
 
-  charNDArray (const string_vector& s) : MArrayN<char> (charMatrix (s)) { }
+  charNDArray (const char *s) : Array<char> (charMatrix (s)) { }
 
-  charNDArray (const ArrayN<char>& a) : MArrayN<char> (a) { }
+  charNDArray (const std::string& s) : Array<char> (charMatrix (s)) { }
+
+  charNDArray (const string_vector& s) : Array<char> (charMatrix (s)) { }
+
+  charNDArray (const Array<char>& a) : Array<char> (a) { }
 
   charNDArray& operator = (const charNDArray& a)
     {
-      MArrayN<char>::operator = (a);
+      Array<char>::operator = (a);
       return *this;
     }
 
@@ -72,17 +75,17 @@ public:
 
   charNDArray& insert (const charNDArray& a, octave_idx_type r, octave_idx_type c);
   charNDArray& insert (const charNDArray& a, const Array<octave_idx_type>& ra_idx);
-  
+
   charMatrix matrix_value (void) const;
 
-  charNDArray squeeze (void) const { return ArrayN<char>::squeeze (); }
+  charNDArray squeeze (void) const { return Array<char>::squeeze (); }
 
   static void increment_index (Array<octave_idx_type>& ra_idx,
-			       const dim_vector& dimensions,
-			       int start_dimension = 0);
+                               const dim_vector& dimensions,
+                               int start_dimension = 0);
 
   static octave_idx_type compute_index (Array<octave_idx_type>& ra_idx,
-			    const dim_vector& dimensions);
+                            const dim_vector& dimensions);
 
   // i/o
 
@@ -93,14 +96,6 @@ public:
 
   charNDArray diag (octave_idx_type k = 0) const;
 
-  typedef int (*mapper) (int);
-  boolNDArray bmap (mapper fcn) const;
-  NDArray dmap (mapper fcn) const;
-  charNDArray smap (mapper fcn) const;
-
-private:
-
-  charNDArray (char *d, dim_vector& dv) : MArrayN<char> (d, dv) { }
 };
 
 NDS_CMP_OP_DECLS (charNDArray, char, OCTAVE_API)
@@ -112,12 +107,6 @@ SND_BOOL_OP_DECLS (char, charNDArray, OCTAVE_API)
 NDND_CMP_OP_DECLS (charNDArray, charNDArray, OCTAVE_API)
 NDND_BOOL_OP_DECLS (charNDArray, charNDArray, OCTAVE_API)
 
-MARRAY_FORWARD_DEFS (MArrayN, charNDArray, char)
+BSXFUN_STDREL_DECLS (charNDArray, OCTAVE_API)
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
