@@ -1,4 +1,4 @@
-## Copyright (C) 2006, 2007 David Bateman
+## Copyright (C) 2006-2012 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -18,8 +18,8 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} acotd (@var{x})
-## Compute the inverse cotangent of an angle in degrees.
-## @seealso{atan, tand}
+## Compute the inverse cotangent in degrees for each element of @var{x}.
+## @seealso{cotd, acot}
 ## @end deftypefn
 
 ## Author: David Bateman <dbateman@free.fr>
