@@ -1,4 +1,5 @@
-## Copyright (C) 2000, 2005, 2006, 2007 Paul Kienzle
+## Copyright (C) 2000-2012 Paul Kienzle
+## Copyright (C) 2008-2009 Jaroslav Hajek
 ##
 ## This file is part of Octave.
 ##
@@ -17,40 +18,38 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} setdiff (@var{a}, @var{b})
+## @deftypefn  {Function File} {} setdiff (@var{a}, @var{b})
 ## @deftypefnx {Function File} {} setdiff (@var{a}, @var{b}, "rows")
+## @deftypefnx {Function File} {[@var{c}, @var{i}] =} setdiff (@var{a}, @var{b})
 ## Return the elements in @var{a} that are not in @var{b}, sorted in
 ## ascending order.  If @var{a} and @var{b} are both column vectors
 ## return a column vector, otherwise return a row vector.
+## @var{a}, @var{b} may be cell arrays of string(s).
 ##
 ## Given the optional third argument @samp{"rows"}, return the rows in
 ## @var{a} that are not in @var{b}, sorted in ascending order by rows.
+##
+## If requested, return @var{i} such that @code{c = a(i)}.
 ## @seealso{unique, union, intersect, setxor, ismember}
 ## @end deftypefn
 
 ## Author: Paul Kienzle
 ## Adapted-by: jwe
 
-function c = setdiff (a, b, byrows_arg)
+function [c, i] = setdiff (a, b, varargin)
 
   if (nargin < 2 || nargin > 3)
     print_usage ();
   endif
 
-  byrows = false;
+  [a, b] = validargs ("setdiff", a, b, varargin{:});
 
-  if (nargin == 3)
-    if (! strcmpi (byrows_arg, "rows"))
-      error ("expecting third argument to be \"rows\"");
-    elseif (iscell (a) || iscell (b))
-      warning ("setdiff: \"rows\" not valid for cell arrays");
+  if (nargin > 2)
+    if (nargout > 1)
+      [c, i] = unique (a, "rows");
     else
-      byrows = true;
+      c = unique (a, "rows");
     endif
-  endif
-
-  if (byrows)
-    c = unique (a, "rows");
     if (! isempty (c) && ! isempty (b))
       ## Form a and b into combined set.
       b = unique (b, "rows");
@@ -58,9 +57,16 @@ function c = setdiff (a, b, byrows_arg)
       ## Eliminate those elements of a that are the same as in b.
       dups = find (all (dummy(1:end-1,:) == dummy(2:end,:), 2));
       c(idx(dups),:) = [];
+      if (nargout > 1)
+        i(idx(dups),:) = [];
+      endif
     endif
   else
-    c = unique (a);
+    if (nargout > 1)
+      [c, i] = unique (a);
+    else
+      c = unique (a);
+    endif
     if (! isempty (c) && ! isempty (b))
       ## Form a and b into combined set.
       b = unique (b);
@@ -69,18 +75,21 @@ function c = setdiff (a, b, byrows_arg)
       if (iscellstr (dummy))
         dups = find (strcmp (dummy(1:end-1), dummy(2:end)));
       else
-	dups = find (dummy(1:end-1) == dummy(2:end));
+        dups = find (dummy(1:end-1) == dummy(2:end));
       endif
       c(idx(dups)) = [];
+      if (nargout > 1)
+        i(idx(dups)) = [];
+      endif
       ## Reshape if necessary.
       if (size (c, 1) != 1 && size (b, 1) == 1)
-	c = c.';
+        c = c.';
       endif
     endif
   endif
-  
+
 endfunction
-  
+
 %!assert(setdiff(["bb";"zz";"bb";"zz"],["bb";"cc";"bb"],"rows"), "zz")
 %!assert(setdiff(["b";"z";"b";"z"],["b";"c";"b"],"rows"), "z")
 %!assert(setdiff(["b";"z";"b";"z"],["b";"c";"b"]), "z")
@@ -88,3 +97,9 @@ endfunction
 %!assert(setdiff([1; 2; 3; 4], [1; 2; 4], "rows"), 3)
 %!assert(setdiff([1, 2; 3, 4], [1, 2; 3, 6], "rows"), [3, 4])
 %!assert(setdiff({"one","two";"three","four"},{"one","two";"three","six"}), {"four"})
+
+%!test
+%! a = [3, 1, 4, 1, 5]; b = [1, 2, 3, 4];
+%! [y, i] = setdiff (a, b.');
+%! assert(y, [5]);
+%! assert(y, a(i));
