@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -35,6 +34,27 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "pr-output.h"
 #include "pt-all.h"
 
+void
+tree_print_code::visit_anon_fcn_handle (tree_anon_fcn_handle& afh)
+{
+  indent ();
+
+  print_parens (afh, "(");
+
+  os << "@(";
+
+  tree_parameter_list *param_list = afh.parameter_list ();
+
+  if (param_list)
+    param_list->accept (*this);
+
+  os << ") ";
+
+  print_fcn_handle_body (afh.body ());
+
+  print_parens (afh, ")");
+}
+
 void
 tree_print_code::visit_argument_list (tree_argument_list& lst)
 {
@@ -45,12 +65,12 @@ tree_print_code::visit_argument_list (tree_argument_list& lst)
       tree_expression *elt = *p++;
 
       if (elt)
-	{
-	  elt->accept (*this);
+        {
+          elt->accept (*this);
 
-	  if (p != lst.end ())
-	    os << ", ";
-	}
+          if (p != lst.end ())
+            os << ", ";
+        }
     }
 }
 
@@ -126,7 +146,7 @@ tree_print_code::visit_continue_command (tree_continue_command&)
 }
 
 void
-tree_print_code::visit_decl_command (tree_decl_command& cmd)
+tree_print_code::do_decl_command (tree_decl_command& cmd)
 {
   indent ();
 
@@ -138,6 +158,18 @@ tree_print_code::visit_decl_command (tree_decl_command& cmd)
     init_list->accept (*this);
 }
 
+void
+tree_print_code::visit_global_command (tree_global_command& cmd)
+{
+  do_decl_command (cmd);
+}
+
+void
+tree_print_code::visit_static_command (tree_static_command& cmd)
+{
+  do_decl_command (cmd);
+}
+
 void
 tree_print_code::visit_decl_elt (tree_decl_elt& cmd)
 {
@@ -166,12 +198,12 @@ tree_print_code::visit_decl_init_list (tree_decl_init_list& lst)
       tree_decl_elt *elt = *p++;
 
       if (elt)
-	{
-	  elt->accept (*this);
+        {
+          elt->accept (*this);
 
-	  if (p != lst.end ())
-	    os << ", ";
-	}
+          if (p != lst.end ())
+            os << ", ";
+        }
     }
 }
 
@@ -182,10 +214,15 @@ tree_print_code::visit_simple_for_command (tree_simple_for_command& cmd)
 
   indent ();
 
-  os << "for ";
+  os << (cmd.in_parallel () ? "parfor " : "for ");
 
   tree_expression *lhs = cmd.left_hand_side ();
 
+  tree_expression *maxproc = cmd.maxproc_expr ();
+
+  if (maxproc)
+    os << "(";
+
   if (lhs)
     lhs->accept (*this);
 
@@ -196,6 +233,13 @@ tree_print_code::visit_simple_for_command (tree_simple_for_command& cmd)
   if (expr)
     expr->accept (*this);
 
+  if (maxproc)
+    {
+      os << ", ";
+      maxproc->accept (*this);
+      os << ")";
+    }
+
   newline ();
 
   tree_statement_list *list = cmd.body ();
@@ -213,7 +257,7 @@ tree_print_code::visit_simple_for_command (tree_simple_for_command& cmd)
 
   indent ();
 
-  os << "endfor";
+  os << (cmd.in_parallel () ? "endparfor" : "endfor");
 }
 
 void
@@ -259,6 +303,17 @@ tree_print_code::visit_complex_for_command (tree_complex_for_command& cmd)
   os << "endfor";
 }
 
+void
+tree_print_code::visit_octave_user_script (octave_user_script& fcn)
+{
+  reset ();
+
+  tree_statement_list *cmd_list = fcn.body ();
+
+  if (cmd_list)
+    cmd_list->accept (*this);
+}
+
 void
 tree_print_code::visit_octave_user_function (octave_user_function& fcn)
 {
@@ -304,26 +359,26 @@ tree_print_code::visit_octave_user_function_header (octave_user_function& fcn)
       int len = ret_list->length ();
 
       if (len > 1 || takes_var_return)
-	{
-	  os << "[";
-	  nesting.push ('[');
-	}
+        {
+          os << "[";
+          nesting.push ('[');
+        }
 
       ret_list->accept (*this);
 
       if (takes_var_return)
-	{
-	  if (len > 0)
-	    os << ", ";
+        {
+          if (len > 0)
+            os << ", ";
 
-	  os << "...";
-	}
+          os << "varargout";
+        }
 
       if (len > 1 || takes_var_return)
-	{
-	  nesting.pop ();
-	  os << "]";
-	}
+        {
+          nesting.pop ();
+          os << "]";
+        }
 
       os << " = ";
     }
@@ -341,27 +396,27 @@ tree_print_code::visit_octave_user_function_header (octave_user_function& fcn)
       int len = param_list->length ();
 
       if (len > 0 || takes_varargs)
-	{
-	  os << "(";
-	  nesting.push ('(');
-	}
+        {
+          os << "(";
+          nesting.push ('(');
+        }
 
       param_list->accept (*this);
 
       if (takes_varargs)
-	{
-	  if (len > 0)
-	    os << ", ";
+        {
+          if (len > 0)
+            os << ", ";
 
-	  os << "...";
-	}
+          os << "varargin";
+        }
 
       if (len > 0 || takes_varargs)
-	{
-	  nesting.pop ();
-	  os << ")";
-	  newline ();
-	}
+        {
+          nesting.pop ();
+          os << ")";
+          newline ();
+        }
     }
   else
     {
@@ -375,11 +430,20 @@ tree_print_code::visit_octave_user_function_trailer (octave_user_function& fcn)
 {
   print_indented_comment (fcn.trailing_comment ());
 
+  newline ();
+}
+
+void
+tree_print_code::visit_function_def (tree_function_def& fdef)
+{
   indent ();
 
-  os << "endfunction";
+  octave_value fcn = fdef.function ();
 
-  newline ();
+  octave_function *f = fcn.function_value ();
+
+  if (f)
+    f->accept (*this);
 }
 
 void
@@ -450,21 +514,21 @@ tree_print_code::visit_if_command_list (tree_if_command_list& lst)
       tree_if_clause *elt = *p++;
 
       if (elt)
-	{
-	  if (! first_elt)
-	    {
-	      print_indented_comment (elt->leading_comment ());
+        {
+          if (! first_elt)
+            {
+              print_indented_comment (elt->leading_comment ());
 
-	      indent ();
+              indent ();
 
-	      if (elt->is_else_clause ())
-		os << "else";
-	      else
-		os << "elseif ";
-	    }
+              if (elt->is_else_clause ())
+                os << "else";
+              else
+                os << "elseif ";
+            }
 
-	  elt->accept (*this);
-	}
+          elt->accept (*this);
+        }
 
       first_elt = false;
     }
@@ -477,16 +541,10 @@ tree_print_code::visit_index_expression (tree_index_expression& expr)
 
   print_parens (expr, "(");
 
-  bool expr_has_parens = false;
-
   tree_expression *e = expr.expression ();
 
   if (e)
-    {
-      e->accept (*this);
-
-      expr_has_parens = e->is_postfix_indexed ();
-    }
+    e->accept (*this);
 
   std::list<tree_argument_list *> arg_lists = expr.arg_lists ();
   std::string type_tags = expr.type_tags ();
@@ -500,56 +558,56 @@ tree_print_code::visit_index_expression (tree_index_expression& expr)
   for (int i = 0; i < n; i++)
     {
       switch (type_tags[i])
-	{
-	case '(':
-	  {
-	    char nc = nesting.top ();
-	    if ((nc == '[' || nc == '{') && expr.paren_count () == 0)
-	      os << "(";
-	    else
-	      os << " (";
-	    nesting.push ('(');
+        {
+        case '(':
+          {
+            char nc = nesting.top ();
+            if ((nc == '[' || nc == '{') && expr.paren_count () == 0)
+              os << "(";
+            else
+              os << " (";
+            nesting.push ('(');
 
-	    tree_argument_list *l = *p_arg_lists;
-	    if (l)
-	      l->accept (*this);
+            tree_argument_list *l = *p_arg_lists;
+            if (l)
+              l->accept (*this);
 
-	    nesting.pop ();
-	    os << ")";
-	  }
-	  break;
-	    
-	case '{':
-	  {
-	    char nc = nesting.top ();
-	    if ((nc == '[' || nc == '{') && expr.paren_count () == 0)
-	      os << "{";
-	    else
-	      os << " {";
-	    // We only care about whitespace inside [] and {} when we
-	    // are defining matrix and cell objects, not when indexing.
-	    nesting.push ('(');
+            nesting.pop ();
+            os << ")";
+          }
+          break;
 
-	    tree_argument_list *l = *p_arg_lists;
-	    if (l)
-	      l->accept (*this);
+        case '{':
+          {
+            char nc = nesting.top ();
+            if ((nc == '[' || nc == '{') && expr.paren_count () == 0)
+              os << "{";
+            else
+              os << " {";
+            // We only care about whitespace inside [] and {} when we
+            // are defining matrix and cell objects, not when indexing.
+            nesting.push ('(');
 
-	    nesting.pop ();
-	    os << "}";
-	  }
-	  break;
-	    
-	case '.':
-	  {
-	    string_vector nm = *p_arg_names;
-	    assert (nm.length () == 1);
-	    os << "." << nm(0);
-	  }
-	  break;
+            tree_argument_list *l = *p_arg_lists;
+            if (l)
+              l->accept (*this);
 
-	default:
-	  panic_impossible ();
-	}
+            nesting.pop ();
+            os << "}";
+          }
+          break;
+
+        case '.':
+          {
+            string_vector nm = *p_arg_names;
+            assert (nm.length () == 1);
+            os << "." << nm(0);
+          }
+          break;
+
+        default:
+          panic_impossible ();
+        }
 
       p_arg_lists++;
       p_arg_names++;
@@ -575,12 +633,12 @@ tree_print_code::visit_matrix (tree_matrix& lst)
       tree_argument_list *elt = *p++;
 
       if (elt)
-	{
-	  elt->accept (*this);
+        {
+          elt->accept (*this);
 
-	  if (p != lst.end ())
-	    os << "; ";
-	}
+          if (p != lst.end ())
+            os << "; ";
+        }
     }
 
   nesting.pop ();
@@ -606,12 +664,12 @@ tree_print_code::visit_cell (tree_cell& lst)
       tree_argument_list *elt = *p++;
 
       if (elt)
-	{
-	  elt->accept (*this);
+        {
+          elt->accept (*this);
 
-	  if (p != lst.end ())
-	    os << "; ";
-	}
+          if (p != lst.end ())
+            os << "; ";
+        }
     }
 
   nesting.pop ();
@@ -634,18 +692,18 @@ tree_print_code::visit_multi_assignment (tree_multi_assignment& expr)
       int len = lhs->length ();
 
       if (len > 1)
-	{
-	  os << "[";
-	  nesting.push ('[');
-	}
+        {
+          os << "[";
+          nesting.push ('[');
+        }
 
       lhs->accept (*this);
 
       if (len > 1)
-	{
-	  nesting.pop ();
-	  os << "]";
-	}
+        {
+          nesting.pop ();
+          os << "]";
+        }
     }
 
   os << " " << expr.oper () << " ";
@@ -697,15 +755,15 @@ tree_print_code::visit_parameter_list (tree_parameter_list& lst)
 
   while (p != lst.end ())
     {
-      tree_identifier *elt = *p++;
+      tree_decl_elt *elt = *p++;
 
       if (elt)
-	{
-	  elt->accept (*this);
+        {
+          elt->accept (*this);
 
-	  if (p != lst.end ())
-	    os << ", ";
-	}
+          if (p != lst.end ())
+            os << ", ";
+        }
     }
 }
 
@@ -761,12 +819,12 @@ tree_print_code::visit_return_list (tree_return_list& lst)
       tree_index_expression *elt = *p++;
 
       if (elt)
-	{
-	  elt->accept (*this);
+        {
+          elt->accept (*this);
 
-	  if (p != lst.end ())
-	    os << ", ";
-	}
+          if (p != lst.end ())
+            os << ", ";
+        }
     }
 }
 
@@ -804,29 +862,29 @@ tree_print_code::visit_statement (tree_statement& stmt)
       cmd->accept (*this);
 
       if (! stmt.print_result ())
-	{
-	  os << ";";
-	  newline (" ");
-	}
+        {
+          os << ";";
+          newline (" ");
+        }
       else
-	newline ();
+        newline ();
     }
   else
     {
       tree_expression *expr = stmt.expression ();
 
       if (expr)
-	{
-	  expr->accept (*this);
+        {
+          expr->accept (*this);
 
-	  if (! stmt.print_result ())
-	    {
-	      os << ";";
-	      newline (" ");
-	    }
-	  else
-	    newline ();
-	}
+          if (! stmt.print_result ())
+            {
+              os << ";";
+              newline (" ");
+            }
+          else
+            newline ();
+        }
     }
 }
 
@@ -838,7 +896,7 @@ tree_print_code::visit_statement_list (tree_statement_list& lst)
       tree_statement *elt = *p;
 
       if (elt)
-	elt->accept (*this);
+        elt->accept (*this);
     }
 }
 
@@ -885,7 +943,7 @@ tree_print_code::visit_switch_case_list (tree_switch_case_list& lst)
       tree_switch_case *elt = *p++;
 
       if (elt)
-	elt->accept (*this);
+        elt->accept (*this);
     }
 }
 
@@ -1090,6 +1148,40 @@ tree_print_code::visit_do_until_command (tree_do_until_command& cmd)
   newline ();
 }
 
+void
+tree_print_code::print_fcn_handle_body (tree_statement_list *b)
+{
+  if (b)
+    {
+      assert (b->length () == 1);
+
+      tree_statement *s = b->front ();
+
+      if (s)
+        {
+          if (s->is_expression ())
+            {
+              tree_expression *e = s->expression ();
+
+              if (e)
+                {
+                  suppress_newlines++;
+                  e->accept (*this);
+                  suppress_newlines--;
+                }
+            }
+          else
+            {
+              tree_command *c = s->command ();
+
+              suppress_newlines++;
+              c->accept (*this);
+              suppress_newlines--;
+            }
+        }
+    }
+}
+
 // Each print_code() function should call this before printing
 // anything.
 //
@@ -1100,17 +1192,14 @@ tree_print_code::indent (void)
 {
   assert (curr_print_indent_level >= 0);
 
-  if (printing_newlines)
+  if (beginning_of_line)
     {
-      if (beginning_of_line)
-	{
-	  os << prefix;
+      os << prefix;
 
-	  for (int i = 0; i < curr_print_indent_level; i++)
-	    os << " ";
+      for (int i = 0; i < curr_print_indent_level; i++)
+        os << " ";
 
-	  beginning_of_line = false;
-	}
+      beginning_of_line = false;
     }
 }
 
@@ -1119,9 +1208,14 @@ tree_print_code::indent (void)
 void
 tree_print_code::newline (const char *alt_txt)
 {
-  os << (printing_newlines ? "\n" : alt_txt);
+  if (suppress_newlines)
+    os << alt_txt;
+  else
+    {
+      os << "\n";
 
-  beginning_of_line = true;
+      beginning_of_line = true;
+    }
 }
 
 // For ressetting print_code state.
@@ -1166,32 +1260,32 @@ tree_print_code::print_comment_elt (const octave_comment_elt& elt)
       char c = comment[i++];
 
       if (c == '\n')
-	{
-	  if (prev_char_was_newline)
-	    os << "##";
+        {
+          if (prev_char_was_newline)
+            os << "##";
 
-	  newline ();
+          newline ();
 
-	  prev_char_was_newline = true;
-	}
+          prev_char_was_newline = true;
+        }
       else
-	{
-	  if (beginning_of_line)
-	    {
-	      printed_something = true;
+        {
+          if (beginning_of_line)
+            {
+              printed_something = true;
 
-	      indent ();
+              indent ();
 
-	      os << "##";
+              os << "##";
 
-	      if (! (isspace (c) || c == '!'))
-		os << " ";
-	    }
+              if (! (isspace (c) || c == '!'))
+                os << " ";
+            }
 
-	  os << (char) c;
+          os << static_cast<char> (c);
 
-	  prev_char_was_newline = false;
-	}
+          prev_char_was_newline = false;
+        }
     }
 
   if (printed_something && ! beginning_of_line)
@@ -1206,14 +1300,14 @@ tree_print_code::print_comment_list (octave_comment_list *comment_list)
       octave_comment_list::iterator p = comment_list->begin ();
 
       while (p != comment_list->end ())
-	{
-	  octave_comment_elt elt = *p++;
+        {
+          octave_comment_elt elt = *p++;
 
-	  print_comment_elt (elt);
+          print_comment_elt (elt);
 
-	  if (p != comment_list->end ())
-	    newline ();
-	}
+          if (p != comment_list->end ())
+            newline ();
+        }
     }
 }
 
@@ -1226,9 +1320,3 @@ tree_print_code::print_indented_comment (octave_comment_list *comment_list)
 
   decrement_indent_level ();
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
